@@ -99,6 +99,10 @@ class SimplePOP3SSLRetriever(POP3RetrieverBase, POP3SSLinitMixIn):
         ConfBool(name='delete_dup_msgids', required=False, default=False),
         ConfFile(name='keyfile', required=False, default=None),
         ConfFile(name='certfile', required=False, default=None),
+        ConfFile(name='ca_certs', required=False, default=None),
+        ConfTupleOfStrings(name='ssl_fingerprints', required=False, default=()),
+        ConfString(name='ssl_version', required=False, default=None),
+        ConfString(name='ssl_ciphers', required=False, default=None),
     )
     received_from = None
     received_with = 'POP3-SSL'
@@ -134,7 +138,7 @@ class BrokenUIDLPOP3RetrieverBase(POP3RetrieverBase):
         duplicated IDs are always treated as new messages.'''
         self.log.trace()
 
-    def write_oldmailfile(self, **kwargs):
+    def write_oldmailfile(self, unused, **kwargs):
         '''Short-circuit writing the oldmail file.'''
         self.log.trace()
 
@@ -149,6 +153,7 @@ class BrokenUIDLPOP3RetrieverBase(POP3RetrieverBase):
                 self.msgnum_by_msgid[msgnum] = msgnum
                 self.msgid_by_msgnum[msgnum] = msgnum
                 self.msgsizes[msgnum] = msgsize
+            self.sorted_msgnum_msgid = sorted(self.msgid_by_msgnum.items())
         except poplib.error_proto, o:
             raise getmailOperationError('POP error (%s)' % o)
         self.gotmsglist = True
@@ -199,6 +204,10 @@ class BrokenUIDLPOP3SSLRetriever(BrokenUIDLPOP3RetrieverBase, POP3SSLinitMixIn):
         ConfBool(name='use_apop', required=False, default=False),
         ConfFile(name='keyfile', required=False, default=None),
         ConfFile(name='certfile', required=False, default=None),
+        ConfFile(name='ca_certs', required=False, default=None),
+        ConfTupleOfStrings(name='ssl_fingerprints', required=False, default=()),
+        ConfString(name='ssl_version', required=False, default=None),
+        ConfString(name='ssl_ciphers', required=False, default=None),
     )
     received_with = 'POP3-SSL'
 
@@ -265,6 +274,10 @@ class MultidropPOP3SSLRetriever(MultidropPOP3RetrieverBase, POP3SSLinitMixIn):
         ConfString(name='envelope_recipient'),
         ConfFile(name='keyfile', required=False, default=None),
         ConfFile(name='certfile', required=False, default=None),
+        ConfFile(name='ca_certs', required=False, default=None),
+        ConfTupleOfStrings(name='ssl_fingerprints', required=False, default=()),
+        ConfString(name='ssl_version', required=False, default=None),
+        ConfString(name='ssl_ciphers', required=False, default=None),
     )
     received_from = None
     received_with = 'POP3-SSL'
@@ -355,8 +368,9 @@ class SimpleIMAPRetriever(IMAPRetrieverBase, IMAPinitMixIn):
         ConfInt(name='port', required=False, default=imaplib.IMAP4_PORT),
         ConfString(name='username'),
         ConfPassword(name='password', required=False, default=None),
-        ConfTupleOfStrings(name='mailboxes', required=False,
-                           default="('INBOX', )"),
+        ConfTupleOfUnicode(name='mailboxes', required=False,
+                           default="('INBOX', )", allow_specials=('ALL',)),
+        ConfBool(name='use_peek', required=False, default=True),
         ConfString(name='move_on_delete', required=False, default=None),
         # imaplib.IMAP4.login_cram_md5() requires the (unimplemented)
         # .authenticate(), so we can't do this yet (?).
@@ -394,11 +408,16 @@ class SimpleIMAPSSLRetriever(IMAPRetrieverBase, IMAPSSLinitMixIn):
         ConfInt(name='port', required=False, default=imaplib.IMAP4_SSL_PORT),
         ConfString(name='username'),
         ConfPassword(name='password', required=False, default=None),
-        ConfTupleOfStrings(name='mailboxes', required=False,
-                           default="('INBOX', )"),
+        ConfTupleOfUnicode(name='mailboxes', required=False,
+                           default="('INBOX', )", allow_specials=('ALL',)),
+        ConfBool(name='use_peek', required=False, default=True),
         ConfString(name='move_on_delete', required=False, default=None),
         ConfFile(name='keyfile', required=False, default=None),
         ConfFile(name='certfile', required=False, default=None),
+        ConfFile(name='ca_certs', required=False, default=None),
+        ConfTupleOfStrings(name='ssl_fingerprints', required=False, default=()),
+        ConfString(name='ssl_version', required=False, default=None),
+        ConfString(name='ssl_ciphers', required=False, default=None),
         # imaplib.IMAP4.login_cram_md5() requires the (unimplemented)
         # .authenticate(), so we can't do this yet (?).
         ConfBool(name='use_cram_md5', required=False, default=False),
@@ -434,8 +453,9 @@ class MultidropIMAPRetriever(MultidropIMAPRetrieverBase, IMAPinitMixIn):
         ConfInt(name='port', required=False, default=imaplib.IMAP4_PORT),
         ConfString(name='username'),
         ConfPassword(name='password', required=False, default=None),
-        ConfTupleOfStrings(name='mailboxes', required=False,
-                           default="('INBOX', )"),
+        ConfTupleOfUnicode(name='mailboxes', required=False,
+                           default="('INBOX', )", allow_specials=('ALL',)),
+        ConfBool(name='use_peek', required=False, default=True),
         ConfString(name='move_on_delete', required=False, default=None),
         # imaplib.IMAP4.login_cram_md5() requires the (unimplemented)
         # .authenticate(), so we can't do this yet (?).
@@ -471,14 +491,19 @@ class MultidropIMAPSSLRetriever(MultidropIMAPRetrieverBase, IMAPSSLinitMixIn):
         # socket.ssl() and socket timeouts are incompatible in Python 2.3
         #ConfInt(name='timeout', required=False, default=180),
         ConfString(name='server'),
-        ConfInt(name='port', required=False, default=110),
+        ConfInt(name='port', required=False, default=imaplib.IMAP4_SSL_PORT),
         ConfString(name='username'),
         ConfPassword(name='password', required=False, default=None),
-        ConfTupleOfStrings(name='mailboxes', required=False,
-                           default="('INBOX', )"),
+        ConfTupleOfUnicode(name='mailboxes', required=False,
+                           default="('INBOX', )", allow_specials=('ALL',)),
+        ConfBool(name='use_peek', required=False, default=True),
         ConfString(name='move_on_delete', required=False, default=None),
         ConfFile(name='keyfile', required=False, default=None),
         ConfFile(name='certfile', required=False, default=None),
+        ConfFile(name='ca_certs', required=False, default=None),
+        ConfTupleOfStrings(name='ssl_fingerprints', required=False, default=()),
+        ConfString(name='ssl_version', required=False, default=None),
+        ConfString(name='ssl_ciphers', required=False, default=None),
         # imaplib.IMAP4.login_cram_md5() requires the (unimplemented)
         # .authenticate(), so we can't do this yet (?).
         ConfBool(name='use_cram_md5', required=False, default=False),
